@@ -4,7 +4,7 @@ from urllib.parse import urlparse
 
 def otx(host, page):
 	these_params = set()
-	data = requests.get('https://otx.alienvault.com/api/v1/indicators/hostname/%s/url_list?limit=50&page=%d' % (host, page), verify=False).json()
+	data = requests.get('https://otx.alienvault.com/api/v1/indicators/hostname/%s/url_list?limit=50&page=%d' % (host, page+1), verify=False).json()
 	if 'url_list' not in data:
 		return (these_params, False, 'otx')
 	for obj in data['url_list']:
